@@ -5,7 +5,7 @@ Created on Mon Nov 25 14:33:25 2019
 
 @author: gc4217
 """
-
+from scipy.optimize import curve_fit
 import numpy as np
 import os
 
@@ -86,3 +86,11 @@ def max_freq(dt_ps, tau):
     else:
         meta = int(tau/2*25/max_freq)
     return meta
+
+def fit_to_lorentzian(x_data, y_data, k, n):
+    if(n in [0,1,2] and np.allclose(k, [0,0,0])): #if acoustic modes at Gamma, don't fit anything
+            popt, pcov = np.zeros(3), np.zeros((3,3))
+    else:
+        popt, pcov = curve_fit(lorentzian, x_data, y_data)
+    perr = np.sqrt(np.diag(pcov))
+    return popt, perr
